Class: PasswordGenerator::Railtie

Inherits:
Rails::Railtie
  • Object
show all
Defined in:
lib/password_generator/railtie.rb

Overview

The Railtie class integrates the Password Generator gem with the Rails framework.

It includes the ViewHelper module in the ActionView::Base class, making the random_password_tag helper method available for use in Rails views.